CommandsMathFunction class

Inheritance

Constructors

CommandsMathFunction(String name, List<Command> commands, {List<String> aliases = const []})
const

Properties

aliases List<String>
finalinherited
commands List<Command>
final
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

evaluate(CalcContext context, Decimal x) EvalResult
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited